SessionManager

Struct SessionManager 

pub struct SessionManager { /* private fields */ }
SessionManager wraps all core state for the MCP server.

Implementations

Source

impl SessionManager

pub fn new(data_dir: &str) -> EvolveResult<Self>

Create a new session manager with optional persistent data directory.

pub fn store_pattern( &mut self, name: &str, domain: &str, language: Language, signature: FunctionSignature, template: &str, variables: Vec<PatternVariable>, confidence: f64, tags: Vec<String>, ) -> EvolveResult<Pattern>

Store a new pattern.

pub fn get_pattern(&self, id: &str) -> EvolveResult<&Pattern>

Get a pattern by ID.

pub fn search_patterns(&self, query: &str) -> Vec<&Pattern>

Search patterns by query.

pub fn list_patterns(&self) -> Vec<&Pattern>

List all patterns.

pub fn delete_pattern(&mut self, id: &str) -> EvolveResult<Pattern>

Delete a pattern by ID.

pub fn match_signature( &self, signature: &FunctionSignature, context: &MatchContext, limit: usize, ) -> EvolveResult<Vec<MatchResult>>

Match a function signature against stored patterns.

pub fn match_context( &self, signature: &FunctionSignature, context: &MatchContext, limit: usize, ) -> EvolveResult<Vec<MatchResult>>

Match patterns with surrounding context.

pub fn crystallize( &mut self, execution: &SuccessfulExecution, ) -> EvolveResult<Vec<Pattern>>

Crystallize successful code into patterns.

pub fn compose( &self, pattern_ids: &[String], bindings: &HashMap<String, String>, ) -> EvolveResult<CompositionResult>

Compose multiple patterns together.

pub fn coverage( &self, signatures: &[FunctionSignature], threshold: f64, ) -> CoverageReport

Get pattern coverage for a set of function signatures.

pub fn confidence(&self, pattern_id: &str) -> EvolveResult<ConfidenceReport>

Get confidence score for a pattern.

pub fn update_usage( &mut self, pattern_id: &str, domain: &str, success: bool, ) -> EvolveResult<()>

Update usage statistics for a pattern.

pub fn optimize(&mut self) -> EvolveResult<OptimizationSummary>

Optimize pattern storage.

pub fn get_body( &self, signature: &FunctionSignature, context: &MatchContext, ) -> EvolveResult<Option<(String, String, f64)>>

Get the function body from the best matching pattern.

pub fn pattern_count(&self) -> usize

Total pattern count.